.. automan documentation master file, created by
   sphinx-quickstart on Thu Aug 23 22:12:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to automan's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview.rst
   tutorial.rst

************************
Reference documentation
************************


.. toctree::
   :maxdepth: 2

   reference/index.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
